@@ -26,8 +26,7 @@ class AbstractConsumer(metaclass=ABCMeta):
     """
 
     def __init__(self, channel, queue, consumer_tag='', no_local=False, no_ack=False,
-                 exclusive=False,
-                 use_thread=False):
+                 exclusive=False, use_thread=False):
         """
         :param channel: channel
         :type channel: amqpy.channel.Channel
@@ -59,8 +58,8 @@ class AbstractConsumer(metaclass=ABCMeta):
         server-assigned consumer tag if a tag was not specified initially.
         """
         self.consumer_tag = self.channel.basic_consume(self.queue, self.consumer_tag, self.no_local,
-                                                       self.no_ack,
-                                                       self.exclusive, callback=self.start,
+                                                       self.no_ack, self.exclusive,
+                                                       callback=self.start,
                                                        on_cancel=self.cancel_cb)
 
     def cancel(self):
